// ignore: implementation_imports, import_of_legacy_library_into_null_safe
import 'package:build/src/builder/build_step.dart';
import 'package:analyzer/dart/element/element.dart' as ele;
import 'package:source_gen/source_gen.dart';
import 'package:build/build.dart';
import 'dart:io';
import 'project.dart';
import 'tpl/tpl.dart' as tpl;

class ProjectGenerator extends GeneratorForAnnotation<GProject> {
  final separator = Platform.pathSeparator;
  final libs = [
    LibInfo(name: 'flutter_localizations', sdk: true),
    LibInfo(name: 'flutter_cupertino_localizations', version: '1.0.1'),
    LibInfo(name: 'observable_builder', version: '0.0.3'),
    LibInfo(name: 'flutter_slidable', version: '0.6.0'),
    LibInfo(name: 'path_provider', version: '2.0.1'),
    LibInfo(name: 'path_parsing', version: '0.2.0'),
    LibInfo(name: 'dio', version: '4.0.0'),
  ];

  String readPubspec(String path) {
    var sb = StringBuffer();
    bool isDev = false;
    try {
      List<String> lines = File(path).readAsLinesSync();
      lines.forEach((line) {
        if (line.startsWith('dependencies:')) {
          isDev = false;
        }
        if (line.startsWith('dev_dependencies:')) {
          isDev = true;
        }
        line = line.replaceAll(RegExp(r'(?<=\>\=).*?(?=\s+\<)'), '2.12.0');
        if (!isDev && line.startsWith('  flutter:')) {
          libs.forEach((lib) {
            if (lib.version != null) {
              sb.writeln('''  ${lib.name}: ^${lib.version}''');
            }
            if (lib.sdk) {
              sb.writeln('''  ${lib.name}:''');
              sb.writeln('''    sdk: flutter''');
            }
          });
        }
        sb.writeln(line);
      });
      sb.writeln('''flutter_intl:''');
      sb.writeln('''  enabled: true''');
      return sb.toString();
    } catch (e) {
      stdout.writeln('文件读取失败! $e');
    }
    return sb.toString();
  }

  @override
  generateForAnnotatedElement(
      ele.Element element, ConstantReader annotation, BuildStep buildStep) {
    var enable = false;
    try {
      enable = annotation.read('enable').boolValue;
    } catch (e) {}
    if (!enable) return null;
    var package = buildStep.inputId.package;
    //初始化第三方库. build.sh
    File('${Directory.current.path}${separator}pubspec.yaml').writeAsStringSync(
        readPubspec('${Directory.current.path}${separator}pubspec.yaml'),
        flush: true);
    File('${Directory.current.path}${separator}build.sh')
      ..createSync(recursive: true)
      ..writeAsStringSync(tpl.Tpl.buildSh(package: package), flush: true);
    //删除main.dart, test
    File('${Directory.current.path}${separator}lib${separator}main.dart')
        .deleteSync();
    File('${Directory.current.path}${separator}test')
        .deleteSync(recursive: true);
    tpl.Tpl.buildCode.forEach((info) {
      var filePath =
          '${Directory.current.path}${separator}lib$separator${info.filePath}';
      File(filePath)
        ..createSync(recursive: true)
        ..writeAsStringSync(info.codeBuild(package: package), flush: true);
    });
    return null;
  }
}

class LibInfo {
  final String name;
  final String? version;
  final bool sdk;

  LibInfo({required this.name, this.version, this.sdk = false});
}

Builder projectBuilder(BuilderOptions options) =>
    LibraryBuilder(ProjectGenerator(), generatedExtension: ".project.dart");
